@@ -18,3 +18,7 @@ class Pais(entity.Entity, db.Model):
                          updated_at, updated_by, tag)
         self.codigo = codigo
         self.nome = nome
+    
+    @classmethod
+    def collection(cls):
+        return 'paises'
